import { createContext, useContext, useState } from 'react';

const LanguageContext = createContext();

export const translations = {
    en: {
        nav: {
            pricing: 'Pricing',
            contact: 'Contact',
            login: 'Login',
            getInTouch: 'Get in touch'
        },
        home: {
            title: 'AI-powered',
            subtitle: 'brand growth',
            description: 'BYOM IS AN AI-POWERED PLATFORM FOCUSING ON HELPING INFLUENCERS GROW THEIR BRAND THROUGH ADVANCED ANALYTICS AND CREATIVE TOOLS.',
            explore: 'Explore features',
            features: {
                aiTrends: 'AI TRENDS',
                imageGen: 'IMAGE GENERATION',
                analytics: 'ANALYTICS',
                brandGrowth: 'BRAND GROWTH'
            }
        },
        pricing: {
            title: 'Pricing',
            subtitle: 'Scale your influence with AI',
            description: 'Choose the perfect plan for your brand\'s growth',
            mostPopular: 'Most popular',
            perMonth: '/month',
            perYear: '/year',
            getStarted: 'Get started with',
            trial: 'All plans include 14-day free trial. No credit card required'
        },
        register: {
            title: 'Create an Account',
            selectedPlan: 'Selected Plan',
            firstName: 'First Name',
            firstNamePlaceholder: 'Enter your first name',
            lastName: 'Last Name',
            lastNamePlaceholder: 'Enter your last name',
            email: 'Email Address',
            emailPlaceholder: 'Enter your email',
        },
        login: {
            title: 'Welcome back',
            subtitle: 'Enter your email to continue',
            continue: 'Continue with email',
            noAccount: 'Don\'t have an account?',
            viewPricing: 'View pricing'
        },
        about: {
            title: 'About BYOM',
            description: 'Empowering creators with AI-driven solutions for brand growth and engagement.',
            mission: {
                title: 'Our Mission',
                description: 'To democratize AI technology for creators and make brand growth accessible to everyone through innovative tools and analytics.'
            },
            timeline: 'Our Journey',
            milestones: {
                founding: 'BYOM Founded',
                founding_desc: 'Started with a vision to revolutionize brand management through AI.',
                launch: 'Platform Launch',
                launch_desc: 'Successfully launched our AI-powered platform to early adopters.',
                growth: 'Global Expansion',
                growth_desc: 'Reached creators in over 50 countries, helping them grow their brands.'
            },
            team: {
                title: 'Meet Our Team',
                sarah: 'Visionary leader with 15 years of experience in AI and brand management.',
                marcus: 'Tech innovator specializing in AI and machine learning solutions.',
                emma: 'Award-winning designer focused on creating intuitive user experiences.'
            },
            roles: {
                ceo: 'CEO & Founder',
                cto: 'CTO',
                design: 'Head of Design'
            },
            contact: {
                title: 'Get in Touch',
                description: `Have questions? We'd love to hear from you. Send us a message and we'll respond as soon as possible.`,
                cta: 'Contact Us'
            }
        },
        aiTrends: {
            title: 'AI Trends',
            description: 'Stay ahead of the curve with our AI trend analysis and insights for brand growth.',
            overview: {
                title: 'Current Trends'
            },
            trends: {
                nlp: {
                    description: 'Advanced language models revolutionizing content creation and analysis.'
                },
                vision: {
                    description: 'Computer vision technologies transforming visual content optimization.'
                },
                generative: {
                    description: 'Generative AI creating new possibilities for brand content and creativity.'
                }
            },
            demo: {
                title: 'See AI in Action',
                description: 'Experience how our AI tools can transform your brand strategy.',
                cta: 'Try Demo'
            },
            stats: {
                title: 'Industry Impact'
            }
        },
        imageGen: {
            title: 'Image Generation',
            description: 'Transform your brand vision into reality with AI-powered image generation.',
            features: {
                title: 'Generation Features',
                styleTransfer: {
                    description: 'Apply your brand style to any image instantly with our AI style transfer technology.'
                },
                product: {
                    description: 'Create professional product visualizations from any angle with customizable settings.'
                },
                social: {
                    description: 'Generate engaging social media content that matches your brand identity.'
                }
            },
            demo: {
                title: 'Try It Yourself',
                description: 'Experience the power of AI image generation with our interactive demo.',
                cta: 'Start Creating'
            },
            styles: {
                title: 'Style Presets'
            }
        },
        analytics: {
            title: 'Analytics Dashboard',
            description: 'Get deep insights into your brand performance with AI-powered analytics.',
            dashboard: {
                title: 'Performance Overview',
                growth: 'Brand Growth',
                engagement: 'Engagement Rate',
                conversion: 'Conversion Rate'
            },
            metrics: {
                title: 'Key Metrics',
                engagement: {
                    description: 'Track engagement across all platforms with real-time analytics and insights.'
                },
                audience: {
                    description: 'Understand your audience with detailed demographic and behavioral analysis.'
                },
                performance: {
                    description: 'Monitor key performance indicators and track progress towards goals.'
                }
            },
            actions: {
                title: 'Quick Actions'
            }
        },
        brandGrowth: {
            title: 'Brand Growth',
            description: 'Accelerate your brand growth with AI-powered strategies and insights.',
            strategies: {
                title: 'Growth Strategies',
                content: {
                    description: 'Data-driven content strategies to maximize engagement and reach.'
                },
                audience: {
                    description: 'Smart audience targeting and growth optimization techniques.'
                },
                identity: {
                    description: 'Build and maintain a strong, consistent brand identity.'
                }
            },
            recommendations: {
                title: 'AI Recommendations',
                content: 'Content Optimization',
                timing: 'Posting Schedule',
                engagement: 'Engagement Strategy'
            },
            tools: {
                title: 'Growth Tools'
            }
        },
        contact: {
            title: 'Contact Us',
            description: 'Get in touch with our team for any questions or support needs.',
            form: {
                title: 'Send us a Message',
                name: 'Your Name',
                email: 'Email Address',
                subject: 'Subject',
                message: 'Your Message',
                send: 'Send Message',
                sending: 'Sending...',
                success: 'Message sent successfully! We\'ll get back to you soon.',
                error: 'There was an error sending your message. Please try again.'
            },
            methods: {
                title: 'Contact Methods',
                email: {
                    title: 'Email Us'
                },
                phone: {
                    title: 'Call Us'
                },
                location: {
                    title: 'Visit Us'
                }
            },
            social: {
                title: 'Follow Us'
            }
        },
        terms: {
            title: 'Terms of Use',
            description: 'Please read these terms carefully before using our services.',
            usage: {
                title: 'Usage Terms',
                content: 'By accessing and using BYOM\'s services, you agree to comply with these terms and all applicable laws and regulations.'
            },
            account: {
                title: 'Account Responsibilities',
                content: 'You are responsible for maintaining the confidentiality of your account credentials and for all activities that occur under your account.'
            },
            intellectual: {
                title: 'Intellectual Property',
                content: 'All content, features, and functionality of BYOM are owned by us and are protected by international copyright, trademark, and other intellectual property laws.'
            },
            liability: {
                title: 'Limitation of Liability',
                content: 'BYOM shall not be liable for any indirect, incidental, special, consequential, or punitive damages resulting from your use of our services.'
            }
        },
        privacy: {
            title: 'Privacy Policy',
            description: 'Learn how we collect, use, and protect your personal information.',
            collection: {
                title: 'Information Collection',
                content: 'We collect information that you provide directly to us, including personal information such as your name, email address, and usage data.'
            },
            usage: {
                title: 'Information Usage',
                content: 'We use the collected information to provide, maintain, and improve our services, as well as to communicate with you.'
            },
            sharing: {
                title: 'Information Sharing',
                content: 'We do not sell or share your personal information with third parties except as described in this policy or with your consent.'
            },
            security: {
                title: 'Data Security',
                content: 'We implement appropriate security measures to protect your personal information against unauthorized access or disclosure.'
            }
        }
    },
    fr: {
        nav: {
            pricing: 'Tarifs',
            contact: 'Contact',
            login: 'Connexion',
            getInTouch: 'Contactez-nous'
        },
        home: {
            title: 'AI-powered',
            subtitle: 'brand growth',
            description: 'BYOM EST UNE PLATEFORME ALIMENTÉE PAR L\'IA QUI AIDE LES INFLUENCEURS À DÉVELOPPER LEUR MARQUE GRÂCE À DES OUTILS D\'ANALYSE AVANCÉS ET CRÉATIFS.',
            explore: 'Explorer les fonctionnalités',
            features: {
                aiTrends: 'TENDANCES IA',
                imageGen: 'GÉNÉRATION D\'IMAGES',
                analytics: 'ANALYSES',
                brandGrowth: 'CROISSANCE DE MARQUE'
            }
        },
        pricing: {
            title: 'Tarifs',
            subtitle: 'Développez votre influence avec l\'IA',
            description: 'Choisissez le forfait parfait pour la croissance de votre marque',
            mostPopular: 'Plus populaire',
            perMonth: '/mois',
            perYear: '/an',
            getStarted: 'Commencer avec',
            trial: 'Tous les forfaits incluent un essai gratuit de 14 jours. Pas de carte bancaire requise'
        },
        register: {
            title: 'Créer un Compte',
            selectedPlan: 'Forfait Sélectionné',
            firstName: 'Prénom',
            firstNamePlaceholder: 'Entrez votre prénom',
            lastName: 'Nom de Famille',
            lastNamePlaceholder: 'Entrez votre nom de famille',
            email: 'Adresse Email',
            emailPlaceholder: 'Entrez votre email',
        },
        login: {
            title: 'Bon retour',
            subtitle: 'Entrez votre email pour continuer',
            continue: 'Continuer avec email',
            noAccount: 'Vous n\'avez pas de compte ?',
            viewPricing: 'Voir les tarifs'
        },
        about: {
            title: 'À Propos de BYOM',
            description: 'Donnons aux créateurs les moyens de réussir avec des solutions basées sur l\'IA pour la croissance et l\'engagement de leur marque.',
            mission: {
                title: 'Notre Mission',
                description: 'Démocratiser la technologie de l\'IA pour les créateurs et rendre la croissance des marques accessible à tous grâce à des outils et des analyses innovants.'
            },
            timeline: 'Notre Parcours',
            milestones: {
                founding: 'Création de BYOM',
                founding_desc: 'Début avec une vision de révolutionner la gestion de marque grâce à l\'IA.',
                launch: 'Lancement de la Plateforme',
                launch_desc: 'Lancement réussi de notre plateforme alimentée par l\'IA auprès des premiers utilisateurs.',
                growth: 'Expansion Mondiale',
                growth_desc: 'Présence dans plus de 50 pays, aidant les créateurs à développer leurs marques.'
            },
            team: {
                title: 'Notre Équipe',
                sarah: 'Leader visionnaire avec 15 ans d\'expérience en IA et gestion de marque.',
                marcus: 'Innovateur tech spécialisé dans les solutions d\'IA et de machine learning.',
                emma: 'Designer primée focalisée sur la création d\'expériences utilisateur intuitives.'
            },
            roles: {
                ceo: 'PDG & Fondatrice',
                cto: 'Directeur Technique',
                design: 'Directrice du Design'
            },
            contact: {
                title: 'Contactez-nous',
                description: 'Des questions ? Nous aimerions avoir de vos nouvelles. Envoyez-nous un message et nous vous répondrons dès que possible.',
                cta: 'Nous Contacter'
            }
        },
        aiTrends: {
            title: 'Tendances IA',
            description: 'Gardez une longueur d\'avance grâce à notre analyse des tendances IA et nos insights pour la croissance de votre marque.',
            overview: {
                title: 'Tendances Actuelles'
            },
            trends: {
                nlp: {
                    description: 'Modèles de langage avancés révolutionnant la création et l\'analyse de contenu.'
                },
                vision: {
                    description: 'Technologies de vision par ordinateur transformant l\'optimisation du contenu visuel.'
                },
                generative: {
                    description: 'L\'IA générative créant de nouvelles possibilités pour le contenu et la créativité des marques.'
                }
            },
            demo: {
                title: 'Voir l\'IA en Action',
                description: 'Découvrez comment nos outils IA peuvent transformer votre stratégie de marque.',
                cta: 'Essayer la Démo'
            },
            stats: {
                title: 'Impact sur l\'Industrie'
            }
        },
        imageGen: {
            title: 'Génération d\'Images',
            description: 'Transformez votre vision de marque en réalité grâce à la génération d\'images par IA.',
            features: {
                title: 'Fonctionnalités de Génération',
                styleTransfer: {
                    description: 'Appliquez instantanément le style de votre marque à n\'importe quelle image avec notre technologie de transfert de style IA.'
                },
                product: {
                    description: 'Créez des visualisations professionnelles de produits sous tous les angles avec des paramètres personnalisables.'
                },
                social: {
                    description: 'Générez du contenu engageant pour les réseaux sociaux qui correspond à l\'identité de votre marque.'
                }
            },
            demo: {
                title: 'Essayez par Vous-même',
                description: 'Découvrez la puissance de la génération d\'images par IA avec notre démo interactive.',
                cta: 'Commencer à Créer'
            },
            styles: {
                title: 'Préréglages de Style'
            }
        },
        analytics: {
            title: 'Tableau de Bord Analytique',
            description: 'Obtenez des insights approfondis sur les performances de votre marque grâce à l\'analyse alimentée par l\'IA.',
            dashboard: {
                title: 'Aperçu des Performances',
                growth: 'Croissance de la Marque',
                engagement: 'Taux d\'Engagement',
                conversion: 'Taux de Conversion'
            },
            metrics: {
                title: 'Métriques Clés',
                engagement: {
                    description: 'Suivez l\'engagement sur toutes les plateformes avec des analyses en temps réel.'
                },
                audience: {
                    description: 'Comprenez votre audience avec une analyse démographique et comportementale détaillée.'
                },
                performance: {
                    description: 'Surveillez les indicateurs de performance clés et suivez les progrès vers les objectifs.'
                }
            },
            actions: {
                title: 'Actions Rapides'
            }
        },
        brandGrowth: {
            title: 'Croissance de Marque',
            description: 'Accélérez la croissance de votre marque avec des stratégies et des insights alimentés par l\'IA.',
            strategies: {
                title: 'Stratégies de Croissance',
                content: {
                    description: 'Stratégies de contenu basées sur les données pour maximiser l\'engagement et la portée.'
                },
                audience: {
                    description: 'Techniques intelligentes de ciblage et d\'optimisation de la croissance de l\'audience.'
                },
                identity: {
                    description: 'Construire et maintenir une identité de marque forte et cohérente.'
                }
            },
            recommendations: {
                title: 'Recommandations IA',
                content: 'Optimisation du Contenu',
                timing: 'Calendrier de Publication',
                engagement: 'Stratégie d\'Engagement'
            },
            tools: {
                title: 'Outils de Croissance'
            }
        },
        contact: {
            title: 'Contactez-nous',
            description: 'Prenez contact avec notre équipe pour toute question ou besoin d\'assistance.',
            form: {
                title: 'Envoyez-nous un Message',
                name: 'Votre Nom',
                email: 'Adresse Email',
                subject: 'Sujet',
                message: 'Votre Message',
                send: 'Envoyer',
                sending: 'Envoi en cours...',
                success: 'Message envoyé avec succès ! Nous vous répondrons bientôt.',
                error: 'Une erreur est survenue lors de l\'envoi. Veuillez réessayer.'
            },
            methods: {
                title: 'Moyens de Contact',
                email: {
                    title: 'Envoyez-nous un Email'
                },
                phone: {
                    title: 'Appelez-nous'
                },
                location: {
                    title: 'Visitez-nous'
                }
            },
            social: {
                title: 'Suivez-nous'
            }
        },
        terms: {
            title: 'Conditions d\'Utilisation',
            description: 'Veuillez lire attentivement ces conditions avant d\'utiliser nos services.',
            usage: {
                title: 'Conditions d\'Utilisation',
                content: 'En accédant et en utilisant les services de BYOM, vous acceptez de vous conformer à ces conditions et à toutes les lois et réglementations applicables.'
            },
            account: {
                title: 'Responsabilités du Compte',
                content: 'Vous êtes responsable de la confidentialité de vos identifiants de compte et de toutes les activités qui se déroulent sous votre compte.'
            },
            intellectual: {
                title: 'Propriété Intellectuelle',
                content: 'Tout le contenu, les fonctionnalités et les fonctions de BYOM nous appartiennent et sont protégés par les lois internationales sur le droit d\'auteur, les marques et autres lois sur la propriété intellectuelle.'
            },
            liability: {
                title: 'Limitation de Responsabilité',
                content: 'BYOM ne sera pas responsable des dommages indirects, accessoires, spéciaux, consécutifs ou punitifs résultant de votre utilisation de nos services.'
            }
        },
        privacy: {
            title: 'Politique de Confidentialité',
            description: 'Découvrez comment nous collectons, utilisons et protégeons vos informations personnelles.',
            collection: {
                title: 'Collecte d\'Informations',
                content: 'Nous collectons les informations que vous nous fournissez directement, y compris les informations personnelles telles que votre nom, adresse email et données d\'utilisation.'
            },
            usage: {
                title: 'Utilisation des Informations',
                content: 'Nous utilisons les informations collectées pour fournir, maintenir et améliorer nos services, ainsi que pour communiquer avec vous.'
            },
            sharing: {
                title: 'Partage d\'Informations',
                content: 'Nous ne vendons ni ne partageons vos informations personnelles avec des tiers, sauf comme décrit dans cette politique ou avec votre consentement.'
            },
            security: {
                title: 'Sécurité des Données',
                content: 'Nous mettons en œuvre des mesures de sécurité appropriées pour protéger vos informations personnelles contre tout accès ou divulgation non autorisé.'
            }
        }
    }
};

export function LanguageProvider({ children }) {
    const [language, setLanguage] = useState('en');

    const value = {
        language,
        setLanguage,
        t: (key) => {
            const keys = key.split('.');
            return keys.reduce((obj, k) => obj?.[k], translations[language]) || key;
        }
    };

    return (
        <LanguageContext.Provider value={value}>
            {children}
        </LanguageContext.Provider>
    );
}

export const useLanguage = () => {
    const context = useContext(LanguageContext);
    if (!context) {
        throw new Error('useLanguage must be used within a LanguageProvider');
    }
    return context;
}; 