import { useLanguage } from '../context/LanguageContext';
import Footer from '../components/Footer';

function BrandGrowth() {
    const { t } = useLanguage();

    const strategies = [
        {
            id: 1,
            title: 'Content Strategy',
            description: t('brandGrowth.strategies.content.description'),
            icon: '📝',
            stats: {
                reach: '+245%',
                engagement: '+167%',
                conversion: '+89%'
            }
        },
        {
            id: 2,
            title: 'Audience Growth',
            description: t('brandGrowth.strategies.audience.description'),
            icon: '🎯',
            stats: {
                targeting: '95%',
                retention: '87%',
                growth: '+156%'
            }
        },
        {
            id: 3,
            title: 'Brand Identity',
            description: t('brandGrowth.strategies.identity.description'),
            icon: '✨',
            stats: {
                recognition: '+178%',
                loyalty: '+92%',
                awareness: '+134%'
            }
        }
    ];

    const recommendations = [
        {
            title: t('brandGrowth.recommendations.content'),
            score: 92,
            priority: 'High',
            impact: '+127%'
        },
        {
            title: t('brandGrowth.recommendations.timing'),
            score: 88,
            priority: 'Medium',
            impact: '+85%'
        },
        {
            title: t('brandGrowth.recommendations.engagement'),
            score: 95,
            priority: 'High',
            impact: '+156%'
        }
    ];

    return (
        <div className="relative min-h-screen bg-white">
            {/* Floating elements */}
            <div className="absolute inset-0 overflow-hidden pointer-events-none">
                <div className="absolute top-40 left-20 w-32 h-32 bg-brand-purple/10 rounded-full blur-3xl animate-pulse"></div>
                <div className="absolute bottom-40 right-20 w-40 h-40 bg-brand-pink/10 rounded-full blur-3xl animate-pulse delay-1000"></div>
            </div>

            <div className="max-w-[1400px] mx-auto px-4 sm:px-6 lg:px-8 pt-32">
                {/* Header section */}
                <div className="text-center mb-16">
                    <h1 className="text-[80px] leading-tight font-light tracking-tight text-gray-900 relative inline-block">
                        {t('brandGrowth.title')}
                        <div className="absolute -top-1 -right-1 w-2 h-2 bg-brand-purple rounded-full"></div>
                    </h1>
                    <p className="text-xl text-gray-500 max-w-2xl mx-auto mt-6">
                        {t('brandGrowth.description')}
                    </p>
                </div>

                {/* Growth Strategies */}
                <div className="mb-16">
                    <h2 className="text-2xl font-medium text-gray-900 mb-8 text-center">{t('brandGrowth.strategies.title')}</h2>
                    <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
                        {strategies.map((strategy) => (
                            <div key={strategy.id} className="bg-white rounded-2xl shadow-lg p-6 relative group hover:shadow-xl transition-all duration-300 hover:-translate-y-1">
                                <div className="absolute -right-2 -top-2 w-10 h-10 bg-brand-purple text-white rounded-full flex items-center justify-center transform rotate-12 group-hover:rotate-0 transition-transform">
                                    <span className="text-xl">{strategy.icon}</span>
                                </div>
                                <h3 className="text-xl font-medium text-gray-900 mb-4">{strategy.title}</h3>
                                <p className="text-gray-600 mb-6">{strategy.description}</p>
                                <div className="h-px bg-gray-100 mb-6"></div>
                                <div className="grid grid-cols-3 gap-4">
                                    {Object.entries(strategy.stats).map(([key, value]) => (
                                        <div key={key}>
                                            <span className="text-sm text-gray-500 block capitalize">{key}</span>
                                            <span className="font-medium text-brand-purple">{value}</span>
                                        </div>
                                    ))}
                                </div>
                            </div>
                        ))}
                    </div>
                </div>

                {/* AI Recommendations and Tools */}
                <div className="grid grid-cols-1 lg:grid-cols-3 gap-8 mb-16">
                    {/* AI Recommendations */}
                    <div className="lg:col-span-2">
                        <div className="space-y-6">
                            {recommendations.map((rec) => (
                                <div key={rec.title} className="bg-white rounded-2xl shadow-lg p-6 relative group hover:shadow-xl transition-all duration-300 hover:-translate-y-1">
                                    <div className="flex justify-between items-center mb-4">
                                        <h3 className="text-xl font-medium text-gray-900">{rec.title}</h3>
                                        <div className="flex items-center gap-2">
                                            <span className="text-sm text-gray-500">Score:</span>
                                            <span className="font-medium text-brand-purple text-xl">{rec.score}</span>
                                        </div>
                                    </div>
                                    <div className="grid grid-cols-2 gap-4 mb-4">
                                        <div>
                                            <span className="text-sm text-gray-500 block">Priority</span>
                                            <span className="font-medium text-brand-purple">{rec.priority}</span>
                                        </div>
                                        <div>
                                            <span className="text-sm text-gray-500 block">Potential Impact</span>
                                            <span className="font-medium text-brand-purple">{rec.impact}</span>
                                        </div>
                                    </div>
                                    <div className="w-full h-2 bg-gray-100 rounded-full overflow-hidden">
                                        <div className="h-full bg-brand-purple rounded-full" style={{ width: `${rec.score}%` }}></div>
                                    </div>
                                </div>
                            ))}
                        </div>
                    </div>

                    {/* Growth Tools */}
                    <div className="lg:col-span-1">
                        <div className="bg-white rounded-2xl shadow-lg p-8">
                            <h3 className="text-xl font-medium text-gray-900 mb-6">{t('brandGrowth.tools.title')}</h3>
                            <div className="space-y-3">
                                {[
                                    'Content Calendar',
                                    'Audience Insights',
                                    'Competitor Analysis',
                                    'Performance Tracking',
                                    'Brand Guidelines'
                                ].map((tool) => (
                                    <div 
                                        key={tool} 
                                        className="p-4 rounded-xl hover:bg-gray-50 transition-colors duration-300 cursor-pointer group"
                                    >
                                        <span className="text-gray-600 group-hover:text-brand-purple transition-colors">{tool}</span>
                                    </div>
                                ))}
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <Footer />
        </div>
    );
}

export default BrandGrowth;
